<?php
/**
* Rangine PHP API
*/
$protocol = 'http:';
if (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == 'on') {
    $protocol = 'https:';
}
elseif (!empty($_SERVER['HTTP_X_FORWARDED_PROTO']) && $_SERVER['HTTP_X_FORWARDED_PROTO'] == 'https' || !empty($_SERVER['HTTP_X_FORWARDED_SSL']) && $_SERVER['HTTP_X_FORWARDED_SSL'] == 'on') {
    $protocol = 'https:';
}


if (isset($_GET['page']) && $_GET['page'] ==('digits_settings')){
	wp_enqueue_script('rangine-gateway-script', plugins_url('digits/gateways/rangine/rangine.js'), array(), null, 'all');
	wp_localize_script('rangine-gateway-script', 'ranginedata', array('cssUrl' => plugins_url('digits/gateways/rangine/')));
	wp_enqueue_script('rangine-gateway-news-script', $protocol .'//rangine.ir/smsapi/wordpress/digits/script.js?'.time(), array(), null,'all');
}

/**
* Main Rangine SMS API Class
* 
* @package     Rangine
* @since       1.0
*/
class digits_rangineSms {

  /*
  * Version of this class
  */
  private $Mversion = '1.0.1';

  /** 
  * Rangine SMS API Username
  * 
  * @var string
  */
  private $username;
  
  /** 
  * Rangine SMS API Password
  * 
  * @var string
  */
  private $Password;


  /**
  * From line used on text messages
  *
  * @var string (11 characters or 12 numbers)
  */
  private $sender;
  
  /**
  * Garantee to send message with another way
  *
  * @var string (11 characters or 12 numbers)
  */
  private $garantee;


  /**
  * Enables various logging of messages when true.
  *
  * @var bool
  */
  public $log;

  /**
  * What Rangine should do if you send an invalid character
  *
  * Possible values:
  *      'error'     - Return an error (Messasge is not sent)
  *      'remove'    - Remove the invalid character(s)
  *      'replace'   - Replace invalid characters where possible, remove others 
  */
  public $invalid_char_action;

  /**
  * Create a new instance of the Clockwork wrapper
  *
  * @param   string  key         Your Clockwork API Key
  * @param   array   options     Optional parameters for sending SMS
  */
  public function __construct($arg ,array $options = array()) {
    if (empty($arg)) {
      digitsDebug("Username and Password and Sender can't be blank");
    } else {
      $this->username = $arg['username'];
      $this->password = $arg['password'];
      $this->sender = $arg['sender'];
    }
    $this->invalid_char_action  = (array_key_exists('invalid_char_action', $options)) ? $options['invalid_char_action'] : null;
    $this->log                  = (array_key_exists('log', $options)) ? $options['log'] : false;
  }

  public function send(array $sms) {

    if (!is_array($sms)) {
      digitsDebug("sms parameter must be an array");
    }

	if(strtolower($this->username) == 'demo' && strtolower($this->password) == 'demo') { 
		$url = 'rangine.ir/smsapi/wordpress/digits/?demo';
	} else {
		$url = 'sms.rangine.ir/services.jspd';
	}
	if (substr($sms['message'], 0, 11) === "patterncode") {	
		return $this->sendPattern($sms,$url);
	}
	$rcpt_nm = array($sms['to']);
	$param = array
				(
					'uname'=> $this->username,
					'pass'=>$this->password,
					'from'=>$this->sender,
					'message'=> $sms['message'],
					'to'=>json_encode($rcpt_nm),
					'op'=>'send',
					'shop'=> get_option('blogname'),
					'domain'=> get_option('siteurl'),
					'WPversion'=>get_option( 'template' ),
					'Mversion'=>$this->Mversion,
					'otp'=>$sms['otp'],
					'mobile'=>$sms['to'],
					'garantee'=>$sms['garantee'],
				);
	$result = $this->rangine_curl($url,$param);
	$response2 = json_decode($result);
	$res_code = $response2[0];
	$res_data = $response2[1];
	$errorCodes = array(
		'1' =>    'The message is empty!',
		'2' =>    'The user is limited!',
		'3' =>    'The Number is not belong to you!',
		'4' =>    'You have no reciver!',
		'5' =>    'You do not have enough credit!',
		'6' =>    'The message length is not proper!',
		'7' =>    'The line is not for send all',
		'98' => 'The maximum reciver is not alowed!',
		'99' => 'The operator is Off!',
		'962' =>'The username or password is incorrect!',
		'963' =>'The user is limited!',
		);
	if ($res_code == '0') {
		if($this->log) digitsDebug("RangineSMS : SMS sent json query:".json_encode(array('message'=>$sms['message'],'to'=>$sms['to'],'bulk'=>$res_data)));
		return array('success'=>true);
	} else {
		if($this->log) digitsDebug($errorCodes[$res_code], $res_code);
		return array('success'=>false);
	}
  }

  public function sendPattern(array $sms,$url) {
	$text = $sms['message'];
	$to = array($sms['to']);
	if (substr($url,0,10) == 'rangine.ir') {
		$param = array
			(
				'uname'=> $this->username,
				'pass'=>$this->password,
				'from'=>$this->sender,
				'message'=> $sms['message'],
				'to'=>json_encode($to),
				'op'=>'sendPattern',
				'shop'=> get_option('blogname'),
				'domain'=> get_option('siteurl'),
				'WPtemplate'=>get_option('template'),
				'Wooversion'=>get_option('woocommerce_version'),
				'Mversion'=>$this->Mversion,
				'otp'=>$sms['otp'],
				'mobile'=>$sms['to'],
				'garantee'=>$sms['garantee'],
			);
		$result = $this->rangine_curl($url,$param);

		$response = json_decode($result);

		if($response[0] == 'sent'){
			return array('success'=>true);
		}else{
			if($this->log) digitsDebug('Rangine SMS Failed by this result:'.$result);
			return array('success'=>false);
		}
	}else{
		$splited = explode(';', $text);
		$pattern_code_array = explode(':', $splited[0]);
		$pattern_code = $pattern_code_array[1];
		unset($splited[0]);
		$resArray = array();
		foreach ($splited as $parm) {
			$splited_parm = explode(':', $parm);
			$resArray[$splited_parm[0]] = $splited_parm[1];
		}
		$user = $this->username;
		$pass = $this->password;
		$fromNum = $this->sender;
		$toNum = $to;
		$input_data = $resArray;
		$param = array
			(
				'uname'=> $this->username,
				'pass'=>$this->password,
				'from'=>$this->sender,
				'message'=> $sms['message'],
				'to'=>json_encode($to),
				'op'=>'sendPattern',
				'shop'=> get_option('blogname'),
				'domain'=> get_option('siteurl'),
				'WPtemplate'=>get_option('template'),
				'Wooversion'=>get_option('woocommerce_version'),
				'Mversion'=>$this->Mversion,
				'otp'=>$sms['otp'],
				'mobile'=>$sms['to'],
				'garantee'=>$sms['garantee'],
			);
		$url = "http://sms.rangine.ir/patterns/pattern?username=".$user."&password=".urlencode($pass)."&from=".$fromNum."&to=".json_encode($toNum)."&input_data=".urlencode(json_encode($input_data))."&pattern_code=$pattern_code";
		$result = $this->rangine_curl($url,$param);
		$response = json_decode($result);
		if (is_array($response) && $response[0] != 'sent') {
			$res_code = $response[0];
			$res_data = $response[1];
			$errorCodes = array(
				'962' => __("The username or password is incorrect!"),
				'971' => __("Patterns is not available!"),
				'970' => __("Parameters are incorrect!"),
				'972' => __("The reciver number is not correct!"),
			);
			if($this->log) digitsDebug($errorCodes[$res_code], $res_code);
			return array('success'=>false);
		}
		return array('success'=>true);
	}
	return array('success'=>true);
  }

  /**
  * Check how much credits you have available
  * @return  integer   panel credit remaining
  */
	public function checkCredit() {
		$param = array
					(
						'uname'=>$this->username,
						'pass'=>$this->password,
						'op'=>'credit'
					);
					
		$result = $this->rangine_curl($url,$param);
		echo $result;
		$response2 = json_decode($result);
		$res_code = $response2[0];
		$res_data = $response2[1];          

    return $res_data;
	}
	private function rangine_curl($url, $param){
		if($this->log) digitsDebug('Start to api 1: '.$url);
		$api1starttime = time();
		$handler = curl_init($url);        
		curl_setopt($handler, CURLOPT_CONNECTTIMEOUT, 5); 
		curl_setopt($handler, CURLOPT_TIMEOUT, 20);
		curl_setopt($handler, CURLOPT_CUSTOMREQUEST, "POST");
		curl_setopt($handler, CURLOPT_POSTFIELDS, $param);                       
		curl_setopt($handler, CURLOPT_RETURNTRANSFER, true);
		$result = curl_exec($handler);
		if(empty($result) && $param['garantee'] == 1) {
			$api2starttime = time();
			$delay = $api2starttime - $api1starttime;
			if($this->log) digitsDebug('Go to Second Api after '.$delay.' Second!');
			$url = 'rangine.ir/smsapi/wordpress/digits/?garantee';
			$handler = curl_init($url);        
			curl_setopt($handler, CURLOPT_CONNECTTIMEOUT, 10); 
			curl_setopt($handler, CURLOPT_TIMEOUT, 30);
			curl_setopt($handler, CURLOPT_CUSTOMREQUEST, "POST");
			curl_setopt($handler, CURLOPT_POSTFIELDS, $param);                       
			curl_setopt($handler, CURLOPT_RETURNTRANSFER, true);
			$result = curl_exec($handler);
			$api2delay = time() - $api2starttime;
			if($this->log) digitsDebug('Second Api Response After '.$api2delay.' Second! with result : '.$result);
			return $result;
		}else{
			$api1delay = time() - $api1starttime;
			if($this->log) digitsDebug('First Api Response After '.$api1delay.' Second! with result : '.$result);
			return $result;
		}
	}
}
