<?php
/**
* Karin Payamak PHP API
*
* @package     Karin Payamak
* @copyright   Karin Payamak 2018
* @license     MIT
* @link        http://http://smskarin.ir
* @version     1.0.1
*/


/**
* Main Karin Payamak API Class
* 
* @package     Karin Payamak
*/
class digits_karinSms {

  /*
  * Version of this class
  */
  private $Mversion = '1.0.1';

  /** 
  * Karin Payamak API Username
  * 
  * @var string
  */
  private $username;
  
  /** 
  * Karin Payamak API Password
  * 
  * @var string
  */
  private $Password;


  /**
  * From line used on text messages
  *
  * @var string (11 characters or 12 numbers)
  */
  private $sender;


  /**
  * Enables various logging of messages when true.
  *
  * @var bool
  */
  public $log;

  /**
  * What Karin Payamak should do if you send an invalid character
  *
  * Possible values:
  *      'error'     - Return an error (Messasge is not sent)
  *      'remove'    - Remove the invalid character(s)
  *      'replace'   - Replace invalid characters where possible, remove others 
  */
  public $invalid_char_action;

  /**
  * Create a new instance of the Clockwork wrapper
  *
  * @param   string  key         Your Clockwork API Key
  * @param   array   options     Optional parameters for sending SMS
  */
  public function __construct($arg ,array $options = array()) {
    if (empty($arg)) {
      error_log("Username and Password and Sender can't be blank");
    } else {
      $this->username = $arg['username'];
      $this->password = $arg['password'];
      $this->sender = $arg['sender'];
    }
    $this->invalid_char_action  = (array_key_exists('invalid_char_action', $options)) ? $options['invalid_char_action'] : null;
    $this->log                  = (array_key_exists('log', $options)) ? $options['log'] : false;
  }
  public function send(array $sms) {
    if (!is_array($sms)) {
      error_log("sms parameter must be an array");
    }

	$encoding = "UTF-8";//CP1256, CP1252
	$textMessage = iconv($encoding, 'UTF-8//TRANSLIT',$sms['message']);
	
	$sendsms_parameters = array(
		'username' => $this->username,
		'password' => $this->password,
		'from' => $this->sender,
		'to' => array($sms['to']),
		'text' => $textMessage,
		'isflash' => false,
		'udh' => "",
		'recId' => array(0),
		'status' => 0
	);
	$client = new SoapClient("http://87.107.121.52/post/send.asmx?wsdl");
	$status = $client->SendSms($sendsms_parameters)->SendSmsResult;
	$statusCodes = array(
		'0' =>    'نام کاربری و رمز اشتباه',
		'1' =>    'ارسال موفق',
		'2' =>    'کمبود اعتبار',
		'3' =>    'محدودیت ارسال روزانه!',
		'4' =>    'محدودیت در ارسال!',
		'5' =>    'شماره مجازی غیر مجاز!',
		'6' =>    'در صف ارسال',
		'7' => 'کلمات فیلتر شده!',
		);
	if ($status == '1') {
		//if($this->log) error_log("smsKarin : SMS sent json query:".json_encode(array('message'=>$sms['message'],'to'=>$sms['to'],'result'=>$statusCodes[$status])));
		return array('success'=>true);
	} else {
		if($this->log) error_log("smsKarin : SMS failed json query:".json_encode(array('message'=>$sms['message'],'to'=>$sms['to'],'error'=>$statusCodes[$status] ? $statusCodes[$status] : 'Unknow Error:'.$status)));
		return array('success'=>false);
	}
  }

}
