<?php
if (!defined('ABSPATH')) {
    exit;
}


if (!class_exists('Clockwork')) {
    require_once plugin_dir_path(__DIR__) . 'gateways/clockwork/wordpress/class-clockwork-plugin.php';
}


if (!class_exists('Melipayamak\MelipayamakApi')) {
    require_once plugin_dir_path(__DIR__) . 'gateways/melipayamak/autoload.php';
}

require_once plugin_dir_path(__DIR__) . 'Twilio/autoload.php';


require_once plugin_dir_path(__DIR__) . 'libphonenumber/autoload.php';


use Melipayamak\MelipayamakApi;
use Twilio\Rest\Client;


if (function_exists('digit_send_message')) {
    return;
}
function digit_whatsapp_message($countrycode, $mobile, $otp, $dig_messagetemplate, $testCall)
{


    $whatsapp_gateway = get_option('digit_whatsapp_gateway', -1);
    $prefix = 'whatsapp';
    switch ($whatsapp_gateway) {
        case 2:
            $whatsapp = get_option('digit_' . $prefix . 'twilio');
            $whatsappno = $whatsapp['whatsappnumber'];
            $sid = $whatsapp['account_sid'];
            $token = $whatsapp['auth_token'];

            try {
                $client = new Client($sid, $token);
                $result = $client->messages->create(
                    "whatsapp:" . $countrycode . $mobile,
                    array(
                        'From' => "whatsapp:" . $whatsappno,
                        'Body' => $dig_messagetemplate
                    )
                );
            } catch (Exception $e) {
                if ($testCall) {
                    return $e->getMessage();
                }

                return false;
            }

            if ($testCall) {
                return $result;
            }

            return true;
        default:
            return false;
    }
}

function digit_send_message($digit_gateway, $countrycode, $mobile, $otp, $dig_messagetemplate, $testCall = false, $whatsapp = false)
{

    $option_slug = 'digit';
    $gateway_id = $digit_gateway;
    $messagetemplate = $dig_messagetemplate;

    if (!$testCall) {
        $debug = apply_filters('digits_debug', false);
        if ($debug) {
            return true;
        }
    }

    if (str_replace('+', '', $countrycode) == '242') {
        if (substr($mobile, 0, 1) != '0') {
            $mobile = '0' . $mobile;
        }
    }

    if ($whatsapp) {
        return digit_whatsapp_message($countrycode, $mobile, $otp, $dig_messagetemplate, $testCall);
    }

    switch ($digit_gateway) {
        case 2:


            $tiwilioapicred = get_option('digit_twilio_api');


            $twiliosenderid = $tiwilioapicred['twiliosenderid'];


            $sid = $tiwilioapicred['twiliosid'];
            $token = $tiwilioapicred['twiliotoken'];


            try {
                $client = new Client($sid, $token);
                $result = $client->messages->create(
                    $countrycode . $mobile,
                    array(
                        'From' => $twiliosenderid,
                        'Body' => $dig_messagetemplate
                    )
                );
            } catch (Exception $e) {
                if ($testCall) {
                    return $e->getMessage();
                }

                return false;
            }

            if ($testCall) {
                return $result;
            }

            return true;
        case 3:

            $msg91apicred = get_option('digit_msg91_api');


            $authKey = $msg91apicred['msg91authkey'];
            $senderId = $msg91apicred['msg91senderid'];
            $msg91route = $msg91apicred['msg91route'];

            if (empty($msg91route)) {
                $msg91route = 2;
            }
            $message = urlencode($dig_messagetemplate);

            if ($msg91route == 1) {


                $postData = array(
                    'authkey' => $authKey,
                    'mobile' => str_replace("+", "", $countrycode) . $mobile,
                    'message' => $message,
                    'sender' => $senderId,
                    'otp' => $otp,
                    'otp_expiry' => 10
                );


                $url = "https://control.msg91.com/api/sendotp.php?" . http_build_query($postData);
                $ch = curl_init();
                curl_setopt_array($ch, array(
                    CURLOPT_URL => $url,
                    CURLOPT_RETURNTRANSFER => true,
                    CURLOPT_CUSTOMREQUEST => 'GET'

                ));
                curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
                curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);

                $result = curl_exec($ch);


                if ($testCall) {
                    return $result;
                }

                if (curl_errno($ch)) {

                    if ($testCall) {
                        return "curl error:" . curl_errno($ch);
                    }

                    return false;
                }

                curl_close($ch);

            } else {


                $postData = array(
                    'authkey' => $authKey,
                    'mobiles' => str_replace("+", "", $countrycode) . $mobile,
                    'message' => $message,
                    'sender' => $senderId,
                    'route' => 4,
                    'country' => 0
                );


                $url = "https://control.msg91.com/api/sendhttp.php";
                $ch = curl_init();
                curl_setopt_array($ch, array(
                    CURLOPT_URL => $url,
                    CURLOPT_RETURNTRANSFER => true,
                    CURLOPT_POST => true,
                    CURLOPT_POSTFIELDS => $postData

                ));
                curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
                curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);

                $result = curl_exec($ch);


                if (curl_errno($ch)) {
                    if ($testCall) {
                        return "curl error:" . curl_errno($ch);
                    }

                    return false;
                }
                curl_close($ch);

                if ($testCall) {
                    return $result;
                }

                return true;
            }

            return true;

        case 4:
            $apikey = get_option('digit_yunpianapi');

            $data = array('text' => $dig_messagetemplate, 'apikey' => $apikey, 'mobile' => $countrycode . $mobile);


            $ch = curl_init();

            curl_setopt($ch, CURLOPT_HTTPHEADER, array(
                'Accept:text/plain;charset=utf-8',
                'Content-Type:application/x-www-form-urlencoded',
                'charset=utf-8'
            ));
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_TIMEOUT, 10);
            curl_setopt($ch, CURLOPT_POST, 1);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

            curl_setopt($ch, CURLOPT_URL, 'https://sms.yunpian.com/v2/sms/single_send.json');
            curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($data));
            $result = curl_exec($ch);


            if (curl_errno($ch)) {
                if ($testCall) {
                    return "curl error:" . curl_errno($ch);
                }

                return false;
            }
            curl_close($ch);

            if ($testCall) {
                return $result;
            }

            if ($result === false) {
                return false;
            }

            return true;
        case 5:

            $clickatell = get_option('digit_clickatell');

            $apikey = $clickatell['api_key'];
            $from = $clickatell['from'];


            $toarray = array();
            $toarray[] = $countrycode . $mobile;

            $cs_array = array();
            $cs_array['content'] = $dig_messagetemplate;
            if (!empty($from)) {
                $cs_array['from'] = $from;
            }
            $data = $cs_array;
            $data['to'] = $toarray;
            $data_string = json_encode($data);


            $ch = curl_init();


            curl_setopt($ch, CURLOPT_HTTPHEADER, array(
                'Content-Type: application/json',
                'Accept: application/json',
                'Authorization: ' . $apikey,

            ));


            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_TIMEOUT, 10);
            curl_setopt($ch, CURLOPT_POST, 1);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
            curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);

            curl_setopt($ch, CURLOPT_URL, 'https://platform.clickatell.com/messages');
            curl_setopt($ch, CURLOPT_POSTFIELDS, $data_string);
            $result = curl_exec($ch);


            if (curl_errno($ch)) {
                if ($testCall) {
                    return "curl error:" . curl_errno($ch);
                }

                return false;
            }
            curl_close($ch);

            if ($testCall) {
                return $result;
            }

            if ($result === false) {
                return false;
            }


            return true;
        case 6:
            $clicksend = get_option('digit_clicksend');
            $username = $clicksend['apiusername'];
            $apikey = $clicksend['apikey'];
            $from = $clicksend['from'];


            $data = array();
            $message = array();
            $message[0] = array(
                'body' => $dig_messagetemplate,
                'from' => $from,
                'to' => $countrycode . $mobile
            );
            $data['messages'] = $message;

            $ch = curl_init();

            curl_setopt($ch, CURLOPT_HTTPHEADER, array(
                'Content-Type: application/json',
                'Authorization: Basic ' . base64_encode("$username:$apikey")
            ));

            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_TIMEOUT, 10);
            curl_setopt($ch, CURLOPT_POST, 1);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

            curl_setopt($ch, CURLOPT_URL, 'https://rest.clicksend.com/v3/sms/send');
            curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
            $result = curl_exec($ch);


            if (curl_errno($ch)) {
                if ($testCall) {
                    return "curl error:" . curl_errno($ch);
                }

                return false;
            }
            curl_close($ch);

            if ($result === false) {
                return false;
            }

            if ($testCall) {
                return $result;
            }

            return true;
        case 7:

            try {


                $clockwork = get_option('digit_clockwork');


                $clockworkapi = $clockwork['clockworkapi'];
                $from = $clockwork['from'];


                $clockwork = new WordPressClockwork($clockworkapi);

                // Setup and send a message
                $message = array(
                    'from' => $from,
                    'to' => str_replace("+", "", $countrycode) . $mobile,
                    'message' => $dig_messagetemplate
                );
                $result = $clockwork->send($message);

                // Check if the send was successful
                if ($result['success']) {

                    if ($testCall) {
                        return $result;
                    }

                    return true;

                } else {
                    return false;
                }
            } catch (ClockworkException $e) {
                if ($testCall) {
                    return $e->getMessage();
                }

                return false;

            }
        case 8:

            $messagebird = get_option('digit_messagebird');
            $accesskey = $messagebird['accesskey'];
            $originator = $messagebird['originator'];
            $data = array(
                'body' => $dig_messagetemplate,
                'originator' => $originator,
                'recipients' => str_replace("+", "", $countrycode) . $mobile
            );


            $ch = curl_init();

            curl_setopt($ch, CURLOPT_HTTPHEADER, array(
                'Accept: application/json',
                'Content-Type: application/json',
                'Authorization: AccessKey ' . $accesskey
            ));
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_TIMEOUT, 10);
            curl_setopt($ch, CURLOPT_POST, 1);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

            curl_setopt($ch, CURLOPT_URL, 'https://rest.messagebird.com/messages?access_key=' . $accesskey);
            curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
            $result = curl_exec($ch);
            curl_close($ch);

            if (curl_errno($ch)) {
                if ($testCall) {
                    return "curl error:" . curl_errno($ch);
                }

                return false;
            }

            if ($testCall) {
                return $result;
            }

            if ($result === false) {
                return false;
            }

            return true;

        case 10:
            $nexmo = get_option('digit_nexmo');
            $from = $nexmo['from'];
            $apikey = $nexmo['api_key'];
            $apisecret = $nexmo['api_secret'];

            $data = array(
                'text' => $dig_messagetemplate,
                'to' => $countrycode . $mobile,
                'from' => $from,
                'type' => 'unicode',
                'api_key' => $apikey,
                'api_secret' => $apisecret
            );


            $ch = curl_init();


            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_TIMEOUT, 10);
            curl_setopt($ch, CURLOPT_POST, 1);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

            curl_setopt($ch, CURLOPT_URL, 'https://rest.nexmo.com/sms/json');
            curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($data));
            $result = curl_exec($ch);


            if (curl_errno($ch)) {
                if ($testCall) {
                    return "curl error:" . curl_errno($ch);
                }

                return false;
            }
            curl_close($ch);

            if ($testCall) {
                return $result;
            }

            if ($result === false) {
                return false;
            }

            return true;
        case 11:
            $pilvo = get_option('digit_plivo');
            if (empty($pilvo) || !$pilvo) {
                $pilvo = get_option('digit_pilvo');
            }
            $authid = $pilvo['auth_id'];
            $authtoken = $pilvo['auth_token'];
            $sender_id = $pilvo['sender_id'];

            $data = array(
                'text' => $dig_messagetemplate,
                'src' => $sender_id,
                'dst' => $countrycode . $mobile,
            );


            $ch = curl_init();

            curl_setopt($ch, CURLOPT_USERPWD, $authid . ":" . $authtoken);

            curl_setopt($ch, CURLOPT_HTTPHEADER, array('Content-Type: application/json'));
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_TIMEOUT, 10);
            curl_setopt($ch, CURLOPT_POST, 1);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

            curl_setopt($ch, CURLOPT_URL, 'https://api.plivo.com/v1/Account/' . $authid . '/Message/');
            curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
            $result = curl_exec($ch);


            if (curl_errno($ch)) {
                if ($testCall) {
                    return "curl error:" . curl_errno($ch);
                }

                return false;
            }
            curl_close($ch);

            if ($testCall) {
                return $result;
            }

            if ($result === false) {
                return false;
            }

            return true;
        case 12:

            $smsapi = get_option('digit_smsapi');
            $token = $smsapi['token'];
            $from = $smsapi['from'];
            $params = array(
                'to' => str_replace("+", "", $countrycode) . $mobile,
                'from' => $from,
                'message' => $dig_messagetemplate,
            );

            $url = 'https://api.smsapi.com/sms.do';
            $c = curl_init();
            curl_setopt($c, CURLOPT_URL, $url);
            curl_setopt($c, CURLOPT_POST, true);
            curl_setopt($c, CURLOPT_POSTFIELDS, $params);
            curl_setopt($c, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($c, CURLOPT_SSL_VERIFYPEER, false);
            curl_setopt($c, CURLOPT_HTTPHEADER, array(
                "Authorization: Bearer $token"
            ));

            $content = curl_exec($c);
            $http_status = curl_getinfo($c, CURLINFO_HTTP_CODE);


            if ($testCall) {
                return $content;
            }

            if (curl_errno($c)) {
                if ($testCall) {
                    return "curl error:" . curl_errno($c);
                }

                return false;
            }

            curl_close($c);

            if ($http_status != 200) {
                return false;
            }

            return true;
        case 33:
            return apply_filters('unitedover_send_sms_with_otp', false, $option_slug, $gateway_id, $countrycode, $mobile, $messagetemplate, $otp, $testCall);
        case 13:
            return true;
        case 14:
            $unifonic = get_option('digit_unifonic');
            $app_sid = $unifonic['appsid'];
            $sender_id = $unifonic['senderid'];

            $params = 'AppSid=' . $app_sid . '&Recipient=' . str_replace("+", "", $countrycode) . $mobile . '&Body=' . $dig_messagetemplate;
            if (!empty($sender_id)) {
                $params = $params . "&SenderID=" . $sender_id;
            }


            $c = curl_init();
            curl_setopt($c, CURLOPT_URL, "http://api.unifonic.com/rest/Messages/Send");
            curl_setopt($c, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($c, CURLOPT_HEADER, false);
            curl_setopt($c, CURLOPT_POST, true);
            curl_setopt($c, CURLOPT_POSTFIELDS, $params);


            curl_setopt($c, CURLOPT_HTTPHEADER, array("Content-Type: application/x-www-form-urlencoded"));
            $result = curl_exec($c);


            if ($testCall) {
                return $result;
            }
            if (curl_errno($c)) {
                if ($testCall) {
                    return "curl error:" . curl_errno($c);
                }

                return false;
            }

            curl_close($c);

            if ($result === false) {
                return false;
            }

            return true;
        case 15:

            $kaleyra = get_option('digit_kaleyra');
            $api_key = $kaleyra['api_key'];
            $sender_id = $kaleyra['sender_id'];
            $curl = curl_init();


            $url = "http://api-alerts.solutionsinfini.com/v4/?method=sms&sender=" . $sender_id . "&to=" . str_replace("+", "", $countrycode) . $mobile . "&message=" . urlencode($dig_messagetemplate) . "&api_key=" . $api_key;

            curl_setopt_array($curl, array(
                CURLOPT_URL => $url,
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_ENCODING => "",
                CURLOPT_MAXREDIRS => 10,
                CURLOPT_TIMEOUT => 30,
                CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                CURLOPT_CUSTOMREQUEST => "GET",
            ));
            $result = curl_exec($curl);

            if (curl_errno($curl)) {
                $result = curl_error($curl);
                if (!$testCall) {
                    return false;
                }
            }
            curl_close($curl);


            if ($testCall) {
                return $result;
            }

            return true;
        case 16:
            $melipayamak = get_option('digit_melipayamak');

            $username = $melipayamak['username'];
            $password = $melipayamak['password'];
            $from = $melipayamak['from'];
            $api = new MelipayamakApi($username, $password);
            $sms = $api->sms();
            $to = '0' . $mobile;
            $result = $sms->send($to, $from, $dig_messagetemplate);
            if ($testCall) {
                return $result;
            }

            return true;

        case 17:
            $textlocal = get_option('digit_textlocal');
            $apiKey = $textlocal['api_key'];
            $sender = $textlocal['sender'];


            $apiKey = urlencode($apiKey);
            $sender = urlencode($sender);
            $message = rawurlencode($dig_messagetemplate);
            $numbers = str_replace("+", "", $countrycode) . $mobile;


            $data = array('apikey' => $apiKey, 'numbers' => $numbers, "sender" => $sender, "message" => $message);


            $ch = curl_init('https://api.textlocal.in/send/');
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            $result = curl_exec($ch);


            if (curl_errno($ch)) {
                $result = curl_error($ch);
                if (!$testCall) {
                    return false;
                }
            }


            curl_close($ch);

            if ($testCall) {
                return $result;
            }


            return true;

        case 20:
            $netgsm = get_option('digit_netgsm');
            $username = $netgsm['username'];
            $password = $netgsm['password'];
            $from = $netgsm['from'];
            $phone = str_replace("+", "", $countrycode) . $mobile;
            $request_url = 'https://api.netgsm.com.tr/sms/send/otp';
            $xml = array(
                'body' => '<?xml version="1.0"?>
                                <mainbody>
                                    <header>
                                        <usercode>' . $username . '</usercode>
                                        <password>' . $password . '</password>
                                        <msgheader>' . $from . '</msgheader>
                                    </header>
                                    <body>
                                        <msg><![CDATA[' . $dig_messagetemplate . ']]></msg>
                                        <no>' . $phone . '</no>
                                    </body>
                                </mainbody>'
            );
            $result = wp_remote_post($request_url, $xml);
            if ($testCall) {
                return $result;
            }

            return true;
        case 21:
            $smsc = get_option('digit_smsc_ru');
            $login = $smsc['login'];
            $psw = $smsc['password'];
            $sender = $smsc['sender'];
            $phone = $countrycode . $mobile;

            $data = array(
                'mes' => $dig_messagetemplate,
                'sender' => $sender,
                'login' => $login,
                'psw' => $psw,
                'phones' => $phone
            );


            $ch = curl_init();

            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
            curl_setopt($ch, CURLOPT_URL, 'https://smsc.ru/sys/send.php?' . http_build_query($data));
            $result = curl_exec($ch);


            curl_close($ch);

            if ($result === false) {
                return false;
            }

            if ($testCall) {
                return $result;
            }

            return true;


        case 26:
            $africastalking = get_option('digit_africastalking');

            $username = $africastalking['username'];
            $api_key = $africastalking['api_key'];
            $from = $africastalking['from'];

            $headers = array(
                'apikey:' . $api_key,
                'Accept: application/json',
                'Content-Type: application/x-www-form-urlencoded',
                'Accept' => 'application/json'
            );

            $params = array(
                "username" => $username,
                "to" => $countrycode . $mobile,
                "message" => $dig_messagetemplate,
                "from" => $from,
            );


            $ch = curl_init();
            curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_CRLF, true);
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
            curl_setopt($ch, CURLOPT_URL, 'https://api.africastalking.com/version1/messaging');
            curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($params));

            $result = curl_exec($ch);
            curl_close($ch);

            if ($result === false) {
                return false;
            }

            if ($testCall) {
                return $result;
            }


            return true;
        case 27:
            /*$cm      = get_option( 'digit_cm' );
            $api_key = $cm['api_key'];
            $from    = $cm['from'];


            if ( $result === false ) {
                return false;
            }

            if ( $testCall ) {
                return $result;
            }

            return true;*/

        case 31:
            $sendinblue = get_option('digit_sendinblue');

            $api_key = $sendinblue['api_key'];
            $sender = $sendinblue['sender'];

            $headers = array(
                'api-key:' . $api_key,
                'accept: application/json',
                'Content-Type: application/json',
                'charset: utf-8'
            );

            $params = array(
                "sender" => $sender,
                "recipient" => $countrycode . $mobile,
                "content" => $dig_messagetemplate,
                "type" => "transactional"
            );


            $ch = curl_init();
            curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_CRLF, true);
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
            curl_setopt($ch, CURLOPT_URL, 'https://api.sendinblue.com/v3/transactionalSMS/sms');
            curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($params));

            $result = curl_exec($ch);
            curl_close($ch);

            if ($result === false) {
                return false;
            }

            if ($testCall) {
                return $result;
            }


            return true;
        case 32:
            $infobip = get_option('digit_infobip');

            $api_key = $infobip['api_key'];
            $base_url = $infobip['base_url'];
            $from = $infobip['from'];

            $curl = curl_init();

            $fields = array(
                'from' => $from,
                'to' => str_replace("+", "", $countrycode) . $mobile,
                'text' => $dig_messagetemplate,
            );

            curl_setopt_array($curl, array(
                CURLOPT_URL => "https://" . $base_url . "/sms/2/text/single",
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_SSL_VERIFYPEER => false,
                CURLOPT_ENCODING => "",
                CURLOPT_MAXREDIRS => 10,
                CURLOPT_TIMEOUT => 30,
                CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                CURLOPT_CUSTOMREQUEST => "POST",
                CURLOPT_POSTFIELDS => json_encode($fields),
                CURLOPT_HTTPHEADER => array(
                    "accept: application/json",
                    "authorization: App " . $api_key,
                    "content-type: application/json"
                ),
            ));

            $response = curl_exec($curl);
            curl_close($curl);

            if ($testCall) {
                return $response;
            }

            if ($response === false) {
                return false;
            }

            return true;
        case 900:
            $messagetemplate = $dig_messagetemplate;

            $gateway = get_option('digit_custom_gateway');
            $url = $gateway['gateway_url'];
            $http_method = $gateway['http_method'];
            $send_body_data = $gateway['send_body_data'];
            $http_headers = explode(',', $gateway['http_header']);

            $attrs = $gateway['gateway_attributes'];

            $sender_id = $gateway['sender_id'];

            $number_type = $gateway['phone_number'];

            if (strtolower($http_method) == 'get') {
                $sender_id = urlencode($sender_id);
            }

            if (!empty($gateway['encode_message'])) {
                $encode_message = $gateway['encode_message'];
                if ($encode_message == 1) {
                    $messagetemplate = urlencode($messagetemplate);
                } else if ($encode_message == 2) {
                    $messagetemplate = UnitedOver_convertToUnicode($messagetemplate);
                }
            }

            if ($number_type == 1) {
                $to = $countrycode . $mobile;
            } else if ($number_type == 2) {
                $to = str_replace("+", "", $countrycode) . $mobile;
            } else {
                $to = $mobile;
            }


            $attrs = str_replace(array("\r", "\n"), '', $attrs);
            $attrs = explode(',', $attrs);


            if (sizeof($attrs) == 1) {
                $attrs = implode(",", $attrs);
                $data = str_replace(array('{to}', '{sender_id}', '{message}'), array($to, $sender_id, $messagetemplate), $attrs);
            } else {
                $data = array();
                foreach ($attrs as $attr) {
                    $params = explode(':', $attr);
                    if (empty($params)) continue;

                    $params = explode(':', $attr, 2);
                    if (empty($params)) continue;
                    $attr_value = '';
                    if (isset($params[1]))
                        $attr_value = str_replace(array('{to}', '{sender_id}', '{message}'), array($to, $sender_id, $messagetemplate), $params[1]);

                    $data[trim($params[0])] = trim($attr_value);
                }
            }

            $ch = curl_init();

            if (strtolower($http_method) == 'get') {
                $url = add_query_arg($data, $url);
            } else {
                if ($send_body_data == 1 && is_array($data)) {
                    $data = json_encode($data);
                }
                curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
            }

            if (!empty($http_headers)) {
                curl_setopt($ch, CURLOPT_HTTPHEADER, $http_headers);
            }


            curl_setopt($ch, CURLOPT_URL, $url);
            curl_setopt($ch, CURLOPT_CUSTOMREQUEST, $http_method);
            curl_setopt($ch, CURLOPT_TIMEOUT, 30);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

            $response = curl_exec($ch);

            curl_close($ch);

            if ($testCall) {
                return $response;
            }

            if ($response === false) {
                return false;
            }

            return true;

        case 38:
            $gateway_fields = get_option($option_slug . '_spryng');

            require_once plugin_dir_path(__DIR__) . 'gateways/spryng.php';

            return \SMSGateway\Spryng::sendSMS(
                $gateway_fields, $countrycode . $mobile, $messagetemplate, $testCall
            );

        case 40:
            $gateway_fields = get_option($option_slug . '_bandwidth');

            require_once plugin_dir_path(__DIR__) . 'gateways/bandwidth.php';

            return \SMSGateway\Bandwidth::sendSMS(
                $gateway_fields, $countrycode . $mobile, $messagetemplate, $testCall
            );
        case 68:
            $gateway_fields = get_option($option_slug . '_esendex');

            require_once plugin_dir_path(__DIR__) . 'gateways/esendex.php';

            return \SMSGateway\Esendex::sendSMS(
                $gateway_fields, $countrycode . $mobile, $messagetemplate, $testCall
            );
        case 71:
            $gateway_fields = get_option($option_slug . '_fortytwo');

            require_once plugin_dir_path(__DIR__) . 'gateways/fortytwo.php';

            return \SMSGateway\FortyTwo::sendSMS(
                $gateway_fields, $countrycode . $mobile, $messagetemplate, $testCall
            );
        case 89:
            $gateway_fields = get_option($option_slug . '_unisender');

            require_once plugin_dir_path(__DIR__) . 'gateways/unisender.php';

            return \SMSGateway\Unisender::sendSMS(
                $gateway_fields, $countrycode . $mobile, $messagetemplate, $testCall
            );
        case 97:
            $gateway_fields = get_option($option_slug . '_sinch');

            require_once plugin_dir_path(__DIR__) . 'gateways/sinch.php';

            return \SMSGateway\Sinch::sendSMS(
                $gateway_fields, $countrycode . $mobile, $messagetemplate, $testCall
            );
        case 101:
            $gateway_fields = get_option($option_slug . '_wavy');

            require_once plugin_dir_path(__DIR__) . 'gateways/wavy.php';

            return \SMSGateway\Wavy::sendSMS(
                $gateway_fields, $countrycode . $mobile, $messagetemplate, $testCall
            );
        case 109:
            $gateway_fields = get_option($option_slug . '_openmarket');

            require_once plugin_dir_path(__DIR__) . 'gateways/openmarket.php';

            return \SMSGateway\OpenMarket::sendSMS(
                $gateway_fields, $countrycode . $mobile, $messagetemplate, $testCall
            );
        case 123:
            $gateway_fields = get_option($option_slug . '_46elks');

            require_once plugin_dir_path(__DIR__) . 'gateways/fortysixelks.php';

            return \SMSGateway\FortySixElks::sendSMS(
                $gateway_fields, $countrycode . $mobile, $messagetemplate, $testCall
            );


        case 400: //kavenegar
            try {
                require_once plugin_dir_path(__DIR__) . 'gateways/kavenegar/class-KavenegarApi.php';
                $gateway = get_option('digit_KaveNegar');
                if (!isset($gateway['kavenegarapi']) || $gateway['kavenegarapi'] == '')
                    return false;
                $api = new digits_KavenegarApi($gateway['kavenegarapi']);
                $sender = $gateway['from'];
                $message = $dig_messagetemplate;
                $receptor = array($mobile);
                // Setup and send a message
                if ($gateway['sample'] == 1) {
                    $result = $api->SendLookup($gateway['kavenegarapi'], $mobile, $gateway['template'], $otp);
                    $resultarray = json_decode($result, true);
                    if ($resultarray['return']['status'] == 200)
                        return true;
                    else
                        return false;
                } else {
                    $result = $api->Send($sender, $receptor, $message);
                }

                if ($result) {
                    foreach ($result as $r) {
                        if (in_array($r->status, array(1, 4, 5)))
                            return true;
                    }
                }
            } catch (\Kavenegar\Exceptions\ApiException $e) {
                // در صورتی که خروجی وب سرویس 200 نباشد این خطا رخ می دهد
                echo $e->errorMessage();
                return false;
            } catch (\Kavenegar\Exceptions\HttpException $e) {
                // در زمانی که مشکلی در برقرای ارتباط با وب سرویس وجود داشته باشد این خطا رخ می دهد
                echo $e->errorMessage();
                return false;
            }
            return false;
        case 401: //rangine
            require_once plugin_dir_path(__DIR__) . 'gateways/rangine/class-RangineSms.php';
            try {
                $rangineSms = get_option('digit_rangine');


                $sample = $rangineSms['sample'];
                $shop_name = $rangineSms['shopname'];
                if ($sample == 1) {
                    if ($shop_name == '') {
                        $dig_messagetemplate = "patterncode:121;activate-code:" . $otp;
                    } else {
                        $dig_messagetemplate = "patterncode:246;app_name:" . $shop_name . ";code:" . $otp;
                    }
                }
                $rangine = new digits_rangineSms($rangineSms);
                $param = array
                (
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                    'otp' => $otp,
                    'garantee' => $rangineSms['garantee']
                );
                // Setup and send a message
                $result = $rangine->send($param);
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                } else {
                    return false;
                }
            } catch (Exception $e) {
                return false;
            }
        case 402://smskarin
            try{
                require_once plugin_dir_path( __DIR__ ).'gateways/smskarin/class-KarinPayamak.php';
                $karin = new digits_karinSms( get_option('digit_karinpayamak') );
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $karin->send( $param );
                // Check if the send was successful
                if($result['success']) {
                    return true;
                } else {
                    return false;
                }
            }
            catch (Exception $e){
                error_log($e);
                return false;
            }
        case 403://payamresan
            try{
                require_once plugin_dir_path( __DIR__ ).'gateways/payamresan/class-payamresan.php';
                $payam_resan = new digits_payamresan( get_option('digit_payamresan') );
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $payam_resan->send( $param );

                // Check if the send was successful
                if($result['success']) {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (Exception $e){
                return false;
            }
        case 404://NikSMS
            try{
                require_once plugin_dir_path( __DIR__ ).'gateways/niksms/class-niksms.php';
                $niksms = new digits_NikSMS( get_option('digit_niksms') );
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $niksms->send( $param );
                // Check if the send was successful
                if($result['success']) {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (Exception $e){
                return false;
            }
        case 405://Modirpayam
            try{
                require_once plugin_dir_path( __DIR__ ).'gateways/modirpayam/class-modirpayam.php';
                $modirpayam = get_option('digit_modirpayam');
                $sample = $modirpayam['sample'];
                $shop_name = $modirpayam['shopname'];
                if ($sample == 1) {
                    if ($shop_name == '') {
                        $dig_messagetemplate = "patterncode:121;activate-code:" . $otp;
                    } else {
                        $dig_messagetemplate = "patterncode:246;app_name:" . $shop_name . ";code:" . $otp;
                    }
                }
                $modirpayam = new digits_modirpayam( $modirpayam );
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $modirpayam->send( $param );
                // Check if the send was successful
                if($result['success']) {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (Exception $e){
                return false;
            }
        case 406://SMS.ir
            try {
                date_default_timezone_set("Asia/Tehran");
                $sms_ir_gateway = get_option('digit_sms_ir');
                if ($sms_ir_gateway['sample'] == 1) {
                    require_once plugin_dir_path(__DIR__) . 'gateways/smsir/class-smsir-fastsend.php';
                    // your sms.ir panel configuration
                    $APIKey = $sms_ir_gateway['apiKey'];
                    $SecretKey = $sms_ir_gateway['secretkey'];
                    $APIURL = "https://ws.sms.ir/";
                    $template = $sms_ir_gateway['template'];
                    $sms_ir_gateway['variables'] = str_replace('%OTP%', $dig_messagetemplate, $sms_ir_gateway['variables']);
                    $variables = explode(';', $sms_ir_gateway['variables']);
                    // message data
                    $data = array(
                        "ParameterArray" => array(),
                        "Mobile" => $mobile,
                        "TemplateId" => $template
                    );
                    foreach ($variables as $variable) {
                        $variablearray = explode(':', $variable);
                        $variablearray = array(
                            "Parameter" => $variablearray[0],
                            "ParameterValue" => $variablearray[1]
                        );
                        $data['ParameterArray'][] = $variablearray;
                    }
                    $SmsIR_UltraFastSend = new digits_SmsIR_UltraFastSend($APIKey, $SecretKey, $APIURL);
                    $UltraFastSend = $SmsIR_UltraFastSend->ultraFastSend($data);
                    if ($UltraFastSend == 'your verification code is sent')
                        return true;
                    else
                        return false;
                }
                elseif ($sms_ir_gateway['clubsend'] == 1) {
                    require_once plugin_dir_path(__DIR__) . 'gateways/smsir/class-smsir-clubsend.php';
                    $APIKey = $sms_ir_gateway['apiKey'];
                    $SecretKey = $sms_ir_gateway['secretkey'];
                    $LineNumber = $sms_ir_gateway['sender'];

                    // your mobile numbers
                    $MobileNumbers = array($mobile);


                    $SmsIR_SendMessage = new digits_SmsIR_ClubAddAndSend($APIKey, $SecretKey, $LineNumber);
                    $SendMessage = $SmsIR_SendMessage->SendMessage($MobileNumbers, $dig_messagetemplate);
                    if ($result !== false)
                        return true;
                    else
                        return false;
                }
                else {
                    require_once plugin_dir_path(__DIR__) . 'gateways/smsir/class-smsir-normalsend.php';
                    $APIKey = $sms_ir_gateway['apiKey'];
                    $SecretKey = $sms_ir_gateway['secretkey'];
                    $LineNumber = $sms_ir_gateway['sender'];

                    // your mobile numbers
                    $MobileNumbers = array($mobile);

                    // your text messages
                    $Messages = array($dig_messagetemplate);


                    $SmsIR_SendMessage = new digits_SmsIR_SendMessage($APIKey, $SecretKey, $LineNumber);
                    $SendMessage = $SmsIR_SendMessage->SendMessage($MobileNumbers, $Messages);
                    if ($result !== false)
                        return true;
                    else
                        return false;
                }
            }
            catch (Exeption $e) {
                error_log('Error SMS.ir : '.$e->getMessage());
            }
        case 407://parsgreen.com
            try {
                require_once plugin_dir_path(__DIR__) . 'gateways/parsgreen/class-parsgreen.php';
                $parsgreengateway = get_option('digit_parsgreen_com');

                $parsgreen = new digits_parsgreen_com($parsgreengateway);
                $param = array
                (
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $parsgreen->send($param);
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                } else {
                    return false;
                }
            }
            catch (Exception $e) {
                return false;
            }
        case 408://nikopayam.com
            try {
                require_once plugin_dir_path(__DIR__) . 'gateways/nikopayam/class-nikopayam.php';
                $nikopayamgateway = get_option('digit_nikopayam_com');
                $nikopayam = new digits_nikopayam($nikopayamgateway);
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $nikopayam->send($param);
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                } else {
                    return false;
                }
            } catch (Exception $e) {
                return false;
            }
        case 409://epayamak.net
            try {
                require_once plugin_dir_path(__DIR__) . 'gateways/epayamak/class-ePayamak.php';
                $epayamak = new digits_ePayamak(get_option('digit_ePayamak_net'));
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $epayamak->send($param);
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                } else {
                    return false;
                }
            } catch (Exception $e) {
                error_log($e);
                return false;
            }
        case 410://Modirpayam
            try {
                require_once plugin_dir_path(__DIR__) . 'gateways/modirpayamak/class-modirpayamak.php';
                $modirpayamak = get_option('digit_modirpayamak_com');
                $sample = $modirpayamak['sample'];
                $shop_name = $modirpayamak['shopname'];
                if ($sample == 1) {
                    if ($shop_name == '') {
                        $dig_messagetemplate = "patterncode:121;activate-code:" . $otp;
                    }
                    else {
                        $dig_messagetemplate = "patterncode:246;app_name:" . $shop_name . ";code:" . $otp;
                    }
                }
                $modirpayamak = new digits_modirpayamak($modirpayamak);
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $modirpayamak->send($param);
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (Exception $e) {
                return false;
            }
        case 411://aradpayamak.net
            try{
                require_once plugin_dir_path(__DIR__) . 'gateways/aradpayamak/class-aradpayamak.php';
                $aradpayamak = new digits_aradpayamak_net(get_option('digit_aradpayamak_net'));
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $aradpayamak->send($param);
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                } else {
                    return false;
                }
            }
            catch (Exception $e) {
                error_log($e);
                return false;
            }
        case 412://FaraPayamak
            try {
                require_once plugin_dir_path(__DIR__) . 'gateways/melipayamak/class-melipayamak.php';
                $meliPayamak = new digits_MeliPayamak(get_option('digit_farapayamak'));
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $meliPayamak->send($param);
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (Exception $e) {
                return false;
            }
        case 413://smshezare.com
            try {
                require_once plugin_dir_path(__DIR__) . 'gateways/smshezare/class-smshezare.php';
                $smshezare = new digits_SMSHezare(get_option('digit_smshezare'));
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $smshezare->send($param);
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (Exception $e) {
                return false;
            }
        case 414://pushit.ir
            try{
                require_once plugin_dir_path(__DIR__) . 'gateways/pushit/class-pushit.php';
                $pushitgateway = get_option('digit_pushit_ir');
                $pushit = new digits_pushit($pushitgateway);
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $pushit->send($param);
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (Exception $e) {
                return false;
            }
        case 415://amnyar.com
            try{
                require_once plugin_dir_path( __DIR__ ).'gateways/amnyar/class-amnyar.php';
                $amnyargateway = get_option('digit_amnyar_com');

                $amnyar = new digits_AmnYar($amnyargateway);
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $amnyar->send($param);
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (Exception $e) {
                return false;
            }
        case 416://18sms.ir
            try{
                require_once plugin_dir_path(__DIR__) . 'gateways/18sms/class-18sms.php';
                $rt_smsgateway = get_option('digit_18sms_ir');

                $rt_sms = new digits_18sms_ir($rt_smsgateway);
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $rt_sms->send($param);
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (Exception $e) {
                return false;
            }
        case 417://melipayamak
            try{
                require_once plugin_dir_path(__DIR__) . 'gateways/melipayamak/class-melipayamak.php';
                $meliPayamakSettings = get_option('digit_meliPayamak');
                $meliPayamak = new digits_MeliPayamak($meliPayamakSettings);
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                    'template' => $meliPayamakSettings['template'],
                );
                // Setup and send a message
                if ($meliPayamakSettings['sample'] == 1) {
                    $result = $meliPayamak->sendPattern($param);
                }
                else {
                    $result = $meliPayamak->send($param);
                }
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (Exception $e) {
                return false;
            }
        case 418://adpdigital
            try {
                require_once plugin_dir_path(__DIR__) . 'gateways/adpdigital/class_adpdigital.php';
                $gateway = get_option('digit_adpdigital');
                $sms = new digits_ADP_SMS_Webservice($gateway['username'], $gateway['password'], $gateway['sender']);
                $countrycode = str_replace('+', '', $countrycode);
                $mobile = substr($mobile, strlen($mobile) - 10, 10);
                $result = $sms->send($countrycode . $mobile, $dig_messagetemplate);
                if (isset($result->sendReturn->status) && $result->sendReturn->status == 0){
                    return true;
                }
            }
            catch (SoapFault $e) {
                echo $e->getMessage();
            }
            return false;
            return false;
        case 419://IppanelSms
            try{
                require_once plugin_dir_path(__DIR__) . 'gateways/ippanel/class-ippanel.php';
                $ippanelSettings = get_option('digit_ippanel');
                $sample = $ippanelSettings['sample'];
                $shop_name = $ippanelSettings['shopname'];
                if ($sample == 1) {
                    if ($shop_name == '') {
                        $dig_messagetemplate = "patterncode:121;activate-code:" . $otp;
                    }
                    else {
                        $dig_messagetemplate = "patterncode:246;app_name:" . $shop_name . ";code:" . $otp;
                    }
                }
                $ippanel = new digits_IppanelSms($ippanelSettings);
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $ippanel->send($param);
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (Exception $e) {
                return false;
            }
        case 420://parsian-sms.ir
            try{
                require_once plugin_dir_path(__DIR__) . 'gateways/parsian-sms/class-parsian-sms.php';
                $parsianSmsgateway = get_option('digit_parsian-sms_ir');
                $parsianSms = new digits_parsian_sms($parsianSmsgateway);
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $parsianSms->send($param);
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (Exception $e) {
                return false;
            }
        case 421://rkasms.ir
            try{
                require_once plugin_dir_path(__DIR__) . 'gateways/rkasms/class-rkasms.php';
                $rkasmsgateway = get_option('digit_rkasms_ir');

                $rkasms = new digits_rkasms_ir($rkasmsgateway);
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $rkasms->send($param);
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                } else {
                    return false;
                }
            } catch (Exception $e) {
                return false;
            }
        case 422://asanak.com
            try{
                require_once plugin_dir_path(__DIR__) . 'gateways/asanak/class-asanak.php';
                $asanakgateway = get_option('digit_asanak_com');
                $asanak = new digits_asanak_com($asanakgateway);
                $param = array
                (
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $asanak->send($param);
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (Exception $e) {
                return false;
            }
        case 423://inoti.ir
            try{
                require_once plugin_dir_path(__DIR__) . 'gateways/inoti/class-inoti.php';
                $inoti = new digits_Inoti(get_option('digit_inoti_ir'));
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $inoti->send($param);
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (Exception $e) {
                return false;
            }
        case 424://FarazSMS
            try{
                require_once plugin_dir_path(__DIR__) . 'gateways/farazsms/class-farazsms.php';
                $farazsms = get_option('digit_farazsms');
                $sample = $farazsms['sample'];
                $shop_name = $farazsms['shopname'];
                if ($sample == 1) {
                    if ($shop_name == '') {
                        $dig_messagetemplate = "patterncode:121;activate-code:" . $otp;
                    }
                    else {
                        $dig_messagetemplate = "patterncode:246;app_name:" . $shop_name . ";code:" . $otp;
                    }
                }
                $farazsms = new digits_farazSms($farazsms);
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $farazsms->send($param);
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (Exception $e) {
                return false;
            }
        case 425://niazpardaz.ir
            try{
                require_once plugin_dir_path(__DIR__) . 'gateways/niazpardaz/class-niazpardaz.php';
                $niazpardazgateway = get_option('digit_niazpardaz_ir');

                $niazpardaz = new digits_niazpardaz_ir($niazpardazgateway);
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $niazpardaz->send($param);
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (Exception $e) {
                return false;
            }
        case 426: //Ghasedak
            $ghasedak = get_option('digit_ghasedak');
            $api_key = $ghasedak['api_key'];
            $headers = array(
                'apikey:' . $api_key,
                'Accept: application/json',
                'Content-Type: application/x-www-form-urlencoded',
                'charset: utf-8'
            );
            $params = array(
                "receptor" => $mobile,
                "message" => $dig_messagetemplate
            );


            $ch = curl_init();
            curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_CRLF, true);
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
            curl_setopt($ch, CURLOPT_URL, 'http://api.ghasedak.io/v2/sms/send/simple');
            curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($params));

            $result = curl_exec($ch);
            curl_close($ch);

            if ($result === false) {
                return false;
            }

            if ($testCall) {
                return $result;
            }


            return true;
        case 427://magfa.com
            try{
                require_once plugin_dir_path(__DIR__) . 'gateways/magfa/class-magfa.php';
                $magfagateway = get_option('digit_magfa');
                $magfa = new digits_magfa($magfagateway);
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $magfa->send($param);
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (Exception $e) {
                return false;
            }
        case 428://SmsOnline
            try{
                require_once plugin_dir_path(__DIR__) . 'gateways/smsonline/class-smsonline.php';
                $smsonline = new digits_SmsOnline(get_option('digit_smsonline'));
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $smsonline->send($param);
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (Exception $e) {
                return false;
            }
        case 429:	//IranSMS
            try{
                require_once plugin_dir_path(__DIR__) . 'gateways/iransms/class-iransms.php';
                $iransms = new digits_IranSMS(get_option('digit_iransms'));
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $iransms->send($param);
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (Exception $e) {
                return false;
            }
        case 430:	//IranSMS
            try{
                require_once plugin_dir_path(__DIR__) . 'gateways/0098/class-0098sms.php';
                $iransms = new digits_0098sms(get_option('digit_0098sms'));
                $param = array(
                    'message' => $dig_messagetemplate,
                    'to' => $mobile,
                );
                // Setup and send a message
                $result = $iransms->send($param);
                // Check if the send was successful
                if ($result['success']) {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (Exception $e) {
                return false;
            }




        case 999:
            $LimeCellular = get_option( 'digit_lime_cellular' );

            $user       = $LimeCellular['user'];
            $api_id     = $LimeCellular['api_id'];
            $short_code = $LimeCellular['short_code'];

            $data = array(
                'message'   => $dig_messagetemplate,
                'user'      => $user,
                'api_id'    => $api_id,
                'shortcode' => $short_code,
                'mobile'    => str_replace( "+", "", $countrycode ) . $mobile
            );


            $ch = curl_init();

            curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
            curl_setopt( $ch, CURLOPT_SSL_VERIFYPEER, false );
            curl_setopt( $ch, CURLOPT_URL, 'https://mcpn.us/sendsmsapi?' . http_build_query( $data ) );
            $result = curl_exec( $ch );


            curl_close( $ch );

            if ( $result === false ) {
                return false;
            }

            return true;

        default:
            return apply_filters('unitedover_send_sms', false, $option_slug, $gateway_id, $countrycode, $mobile, $messagetemplate, $testCall);
    }


}

